@@ -26,6 +26,7 @@ from task_processing.plugins.kubernetes.types import SecretVolume
 from task_processing.plugins.kubernetes.types import SecretVolumeItem
 from task_processing.plugins.kubernetes.utils import get_sanitised_kubernetes_name
 from task_processing.plugins.kubernetes.utils import mode_to_int
+
 if TYPE_CHECKING:
     from task_processing.plugins.kubernetes.types import SecretEnvSource
 
@@ -40,13 +41,13 @@ POD_SUFFIX_LENGTH = 6
 # but let's give ourselves a little buffer so we'll round down a bit
 MAX_POD_NAME_LENGTH = 150
 MAX_DNS_SUBDOMAIN_NAME_LENGTH = 253
-VALID_DNS_SUBDOMAIN_NAME_REGEX = '^[a-z0-9]([-a-z0-9.]*[a-z0-9])?$'
+VALID_DNS_SUBDOMAIN_NAME_REGEX = "^[a-z0-9]([-a-z0-9.]*[a-z0-9])?$"
 VALID_EMPTY_VOLUME_KEYS = set(EmptyVolume.__annotations__.keys())
 VALID_VOLUME_KEYS = set(DockerVolume.__annotations__.keys())
 VALID_SECRET_VOLUME_KEYS = set(SecretVolume.__annotations__.keys())
 VALID_SECRET_VOLUME_ITEM_KEYS = set(SecretVolumeItem.__annotations__.keys())
-VALID_SECRET_ENV_KEYS = {'secret_name', 'key'}
-VALID_FIELD_SELECTOR_ENV_KEYS = {'field_path'}
+VALID_SECRET_ENV_KEYS = {"secret_name", "key"}
+VALID_FIELD_SELECTOR_ENV_KEYS = {"field_path"}
 VALID_CAPABILITIES = {
     "AUDIT_CONTROL",
     "AUDIT_READ",
@@ -109,7 +110,9 @@ REQUIRED_NODE_AFFINITY_KEYS = set(NodeAffinity.__annotations__.keys())
 
 
 def _generate_pod_suffix() -> str:
-    return ''.join(secrets.choice(POD_SUFFIX_ALPHABET) for i in range(POD_SUFFIX_LENGTH))
+    return "".join(
+        secrets.choice(POD_SUFFIX_ALPHABET) for i in range(POD_SUFFIX_LENGTH)
+    )
 
 
 def _valid_volumes(volumes: Sequence[DockerVolume]) -> Tuple[bool, Optional[str]]:
@@ -117,8 +120,8 @@ def _valid_volumes(volumes: Sequence[DockerVolume]) -> Tuple[bool, Optional[str]
         if set(volume.keys()) != VALID_VOLUME_KEYS:
             return (
                 False,
-                f'Invalid volume format, must only contain following keys: '
-                f'{VALID_VOLUME_KEYS}, got: {volume.keys()}'
+                f"Invalid volume format, must only contain following keys: "
+                f"{VALID_VOLUME_KEYS}, got: {volume.keys()}",
             )
         if volume["mode"] not in VALID_DOCKER_VOLUME_MODES:
             return (
@@ -133,10 +136,10 @@ def _valid_empty_volumes(volumes: Sequence[EmptyVolume]) -> Tuple[bool, Optional
         if set(volume.keys()) != VALID_EMPTY_VOLUME_KEYS:
             return (
                 False,
-                f'Invalid empty volume format, must only contain following keys: '
-                f'{VALID_EMPTY_VOLUME_KEYS}, got: {volume.keys()}'
+                f"Invalid empty volume format, must only contain following keys: "
+                f"{VALID_EMPTY_VOLUME_KEYS}, got: {volume.keys()}",
             )
-        if volume['medium'] not in VALID_DOCKER_VOLUME_MEDIUM:
+        if volume["medium"] not in VALID_DOCKER_VOLUME_MEDIUM:
             return (
                 False,
                 f"Invalid medium for empty volume, must be one of {VALID_DOCKER_VOLUME_MEDIUM}",
@@ -144,18 +147,20 @@ def _valid_empty_volumes(volumes: Sequence[EmptyVolume]) -> Tuple[bool, Optional
     return (True, None)
 
 
-def _valid_secret_volumes(volumes: Sequence[SecretVolume]) -> Tuple[bool, Optional[str]]:
+def _valid_secret_volumes(
+    volumes: Sequence[SecretVolume],
+) -> Tuple[bool, Optional[str]]:
     for volume in volumes:
         if set(volume.keys()) != VALID_SECRET_VOLUME_KEYS:
             return (
                 False,
-                f'Invalid volume format, must only contain following keys: '
-                f'{VALID_SECRET_VOLUME_KEYS}, got: {volume.keys()}'
+                f"Invalid volume format, must only contain following keys: "
+                f"{VALID_SECRET_VOLUME_KEYS}, got: {volume.keys()}",
             )
 
-        if volume['default_mode'] is not None:
+        if volume["default_mode"] is not None:
             try:
-                mode_to_int(volume['default_mode'])
+                mode_to_int(volume["default_mode"])
             except (TypeError, ValueError):
                 return (
                     False,
@@ -168,13 +173,13 @@ def _valid_secret_volumes(volumes: Sequence[SecretVolume]) -> Tuple[bool, Option
                 if set(item.keys()) != VALID_SECRET_VOLUME_ITEM_KEYS:
                     return (
                         False,
-                        f'Invalid secret item format, must only contain following keys: '
-                        f'{VALID_SECRET_VOLUME_ITEM_KEYS}, got: {item.keys()}'
+                        f"Invalid secret item format, must only contain following keys: "
+                        f"{VALID_SECRET_VOLUME_ITEM_KEYS}, got: {item.keys()}",
                     )
 
-                if item['mode'] is not None:
+                if item["mode"] is not None:
                     try:
-                        mode_to_int(item['mode'])
+                        mode_to_int(item["mode"])
                     except (TypeError, ValueError):
                         return (
                             False,
@@ -185,14 +190,16 @@ def _valid_secret_volumes(volumes: Sequence[SecretVolume]) -> Tuple[bool, Option
     return (True, None)
 
 
-def _valid_secret_envs(secret_envs: Mapping[str, "SecretEnvSource"]) -> Tuple[bool, Optional[str]]:
+def _valid_secret_envs(
+    secret_envs: Mapping[str, "SecretEnvSource"]
+) -> Tuple[bool, Optional[str]]:
     # Note we are not validating existence of secret in k8s here, leave that to creation of pod
     for key, value in secret_envs.items():
         if set(value.keys()) != VALID_SECRET_ENV_KEYS:
             return (
                 False,
-                f'Invalid secret environment variable {key}, must only contain following keys: '
-                f'{VALID_SECRET_ENV_KEYS}, got: {value.keys()}'
+                f"Invalid secret environment variable {key}, must only contain following keys: "
+                f"{VALID_SECRET_ENV_KEYS}, got: {value.keys()}",
             )
     return (True, None)
 
@@ -206,8 +213,8 @@ def _valid_field_selector_envs(
         if set(value.keys()) != VALID_FIELD_SELECTOR_ENV_KEYS:
             return (
                 False,
-                f'Invalid field selector environment variable {key}, must only contain following '
-                f'keys: {VALID_FIELD_SELECTOR_ENV_KEYS}, got: {value.keys()}'
+                f"Invalid field selector environment variable {key}, must only contain following "
+                f"keys: {VALID_FIELD_SELECTOR_ENV_KEYS}, got: {value.keys()}",
             )
     return (True, None)
 
@@ -222,13 +229,15 @@ def _valid_capabilities(capabilities: Sequence[str]) -> Tuple[bool, Optional[str
     return (True, None)
 
 
-def _valid_node_affinities(affinities: Sequence["NodeAffinity"]) -> Tuple[bool, Optional[str]]:
+def _valid_node_affinities(
+    affinities: Sequence["NodeAffinity"],
+) -> Tuple[bool, Optional[str]]:
     for aff in affinities:
         missing_keys = REQUIRED_NODE_AFFINITY_KEYS.difference(set(aff.keys()))
         if missing_keys:
             return (
                 False,
-                f"Invalid node affinity: got {aff} but missing keys {missing_keys}"
+                f"Invalid node affinity: got {aff} but missing keys {missing_keys}",
             )
 
         op, val = aff["operator"], aff["value"]
@@ -240,19 +249,18 @@ def _valid_node_affinities(affinities: Sequence["NodeAffinity"]) -> Tuple[bool,
                 f"but expected one of: {valid_operators}",
             )
 
-        elif (
-            op in {NodeAffinityOperator.IN, NodeAffinityOperator.NOT_IN} and
-            type(val) not in {list, tuple}
-        ):
+        elif op in {NodeAffinityOperator.IN, NodeAffinityOperator.NOT_IN} and type(
+            val
+        ) not in {list, tuple}:
             return (
                 False,
                 "Invalid node affinity value: "
-                f"got non-list value '{val}' for affinity operator '{op}'"
+                f"got non-list value '{val}' for affinity operator '{op}'",
             )
 
         elif (
-            op in {NodeAffinityOperator.GT, NodeAffinityOperator.LT} and
-            type(val) != int
+            op in {NodeAffinityOperator.GT, NodeAffinityOperator.LT}
+            and type(val) != int
         ):
             return (
                 False,
@@ -280,8 +288,11 @@ def _valid_service_account_name(
     valid_name = bool(re.match(VALID_DNS_SUBDOMAIN_NAME_REGEX, service_account_name))
 
     return (
-        (valid_length, f'Account name length must be >=1,<={MAX_DNS_SUBDOMAIN_NAME_LENGTH}.'),
-        (valid_name, 'Account names must be valid DNS subdomain names.'),
+        (
+            valid_length,
+            f"Account name length must be >=1,<={MAX_DNS_SUBDOMAIN_NAME_LENGTH}.",
+        ),
+        (valid_name, "Account names must be valid DNS subdomain names."),
     )
 
 
@@ -294,14 +305,21 @@ class KubernetesTaskConfig(DefaultTaskConfigInterface):
         valid_length = len(self.pod_name) <= MAX_POD_NAME_LENGTH
         valid_name = bool(re.match(VALID_DNS_SUBDOMAIN_NAME_REGEX, self.pod_name))
 
-        all_ports = list(chain.from_iterable(
-            [self.ports] + [container.ports for container in self.extra_containers.values()]))
+        all_ports = list(
+            chain.from_iterable(
+                [self.ports]
+                + [container.ports for container in self.extra_containers.values()]
+            )
+        )
         duplicate_ports = bool(len(set(all_ports)) == len(all_ports))
 
         return (
-            (valid_length, f'Pod name must have up to {MAX_POD_NAME_LENGTH} characters.'),
-            (valid_name, 'Must comply with Kubernetes pod naming standards.'),
-            (duplicate_ports, 'Containers must define unique ports.'),
+            (
+                valid_length,
+                f"Pod name must have up to {MAX_POD_NAME_LENGTH} characters.",
+            ),
+            (valid_name, "Must comply with Kubernetes pod naming standards."),
+            (duplicate_ports, "Containers must define unique ports."),
         )
 
     uuid = field(type=str, initial=_generate_pod_suffix)  # type: ignore
@@ -314,14 +332,14 @@ class KubernetesTaskConfig(DefaultTaskConfigInterface):
         type=int,
         factory=int,
         mandatory=False,
-        invariant=lambda r: (r >= 0, 'retries >= 0')
+        invariant=lambda r: (r >= 0, "retries >= 0"),
     )
 
     image = field(type=str, mandatory=True)
     command = field(
         type=str,
         mandatory=True,
-        invariant=lambda cmd: (cmd.strip() != '', 'empty command is not allowed')
+        invariant=lambda cmd: (cmd.strip() != "", "empty command is not allowed"),
     )
     volumes = field(
         type=PVector if not TYPE_CHECKING else PVector["DockerVolume"],
@@ -342,37 +360,36 @@ class KubernetesTaskConfig(DefaultTaskConfigInterface):
         factory=pmap,
         invariant=lambda containers: (
             not any([container.extra_containers for container in containers.values()]),
-            'extra_containers cannot have extra_containers',
+            "extra_containers cannot have extra_containers",
         ),
     )
 
     cpus = field(
-        type=float,
-        initial=0.1,
-        factory=float,
-        invariant=lambda c: (c > 0, 'cpus > 0'))
+        type=float, initial=0.1, factory=float, invariant=lambda c: (c > 0, "cpus > 0")
+    )
     cpus_request = field(
         type=(float, type(None)),
         factory=_float_or_none,
-        invariant=lambda c: (c is None or c > 0, 'cpus_request > 0'),
-        initial=None)
+        invariant=lambda c: (c is None or c > 0, "cpus_request > 0"),
+        initial=None,
+    )
 
     memory = field(
         type=float,
         initial=128.0,
         factory=float,
-        invariant=lambda m: (m >= 32, 'mem is >= 32'))
+        invariant=lambda m: (m >= 32, "mem is >= 32"),
+    )
     memory_request = field(
         type=(float, type(None)),
         factory=_float_or_none,
-        invariant=lambda m: (m is None or m >= 32, 'mem_request >= 32'),
-        initial=None)
+        invariant=lambda m: (m is None or m >= 32, "mem_request >= 32"),
+        initial=None,
+    )
 
     disk = field(
-        type=float,
-        initial=10.0,
-        factory=float,
-        invariant=lambda d: (d > 0, 'disk > 0'))
+        type=float, initial=10.0, factory=float, invariant=lambda d: (d > 0, "disk > 0")
+    )
 
     environment = field(
         type=PMap if not TYPE_CHECKING else PMap[str, str],
@@ -380,13 +397,13 @@ class KubernetesTaskConfig(DefaultTaskConfigInterface):
         factory=pmap,
     )
     secret_environment = field(
-        type=PMap if not TYPE_CHECKING else PMap[str, 'SecretEnvSource'],
+        type=PMap if not TYPE_CHECKING else PMap[str, "SecretEnvSource"],
         initial=m(),
         factory=pmap,
         invariant=_valid_secret_envs,
     )
     field_selector_environment = field(
-        type=PMap if not TYPE_CHECKING else PMap[str, 'ObjectFieldSelectorSource'],
+        type=PMap if not TYPE_CHECKING else PMap[str, "ObjectFieldSelectorSource"],
         initial=m(),
         factory=pmap,
         invariant=_valid_field_selector_envs,
@@ -433,7 +450,10 @@ class KubernetesTaskConfig(DefaultTaskConfigInterface):
         # this is the `nobody` user at Yelp, which is what we should always be using
         # and, as such, is probably the best default to add here.
         initial=65534,
-        invariant=lambda group: (0 <= group <= 65534, 'fs_group must be >= 0 and <= 65,534'),
+        invariant=lambda group: (
+            0 <= group <= 65534,
+            "fs_group must be >= 0 and <= 65,534",
+        ),
     )
     service_account_name = field(
         type=(str, type(None)),
@@ -472,14 +492,14 @@ class KubernetesTaskConfig(DefaultTaskConfigInterface):
     @property
     def pod_name(self) -> str:
         return get_sanitised_kubernetes_name(
-            f'{self.name}.{self.uuid}',  # type: ignore
+            f"{self.name}.{self.uuid}",  # type: ignore
             length_limit=MAX_POD_NAME_LENGTH,
         )
 
     def set_pod_name(self, pod_name: str):
         try:
-            name, uuid = pod_name.rsplit('.', maxsplit=1)
+            name, uuid = pod_name.rsplit(".", maxsplit=1)
         except ValueError:
-            raise ValueError(f'Invalid format for pod_name {pod_name}')
+            raise ValueError(f"Invalid format for pod_name {pod_name}")
 
         return self.set(name=name, uuid=uuid)
