@@ -1,6 +1,8 @@
 import enum
 from typing import Any
 from typing import Dict
+from typing import List
+from typing import Optional
 
 from kubernetes.client import V1Pod
 from typing_extensions import TypedDict
@@ -12,6 +14,26 @@ class DockerVolume(TypedDict):
     mode: str  # XXX: Literal["RO", "RW"] once we drop older Python support
 
 
+class EmptyVolume(TypedDict):
+    container_path: str
+    medium: Optional[str]  # XXX: Optional[Literal["Memory"]] In this case
+    size: Optional[str]  # XXX: implement a validator for this
+
+
+class SecretVolumeItem(TypedDict):
+    key: str
+    path: str
+    mode: Optional[str]  # octal permissions mode
+
+
+class SecretVolume(TypedDict):
+    secret_volume_name: str
+    secret_name: str
+    container_path: str
+    default_mode: Optional[str]  # octal permissions mode
+    items: List[SecretVolumeItem]
+
+
 class SecretEnvSource(TypedDict):
     secret_name: str  # full name of k8s secret resource
     key: str
